@@ -12,7 +12,7 @@ class Rest:
 
 @dataclass
 class Work:
-    mins: int = TIMER_DEFAULTS["work"]["secs"]
+    mins: int = TIMER_DEFAULTS["work"]["mins"]
     secs: int = TIMER_DEFAULTS["work"]["secs"]
     bar_color: str = Fore.RED
 
