@@ -12,12 +12,10 @@ from sylo.messages import (
 )
 from sylo.models import Durations
 from sylo.definitions import (
-    AUDIO_FILE_PATH,
     WELCOME_CHOICES,
     COUNTDOWN_INCREMENTS,
 )
 from sylo.utils import (
-    get_first_file_in_directory,
     clear_screen,
     mins_to_secs,
     flip_mode,
@@ -25,6 +23,7 @@ from sylo.utils import (
 
 
 is_double = False
+timer_mode = 'work'
 
 
 class Timer:
@@ -66,18 +65,17 @@ class Timer:
 
 class Sound:
 
-    def __init__(self):
-        self.sound_file = AUDIO_FILE_PATH
+    def __init__(self, audio_path: str = 'dummy'):
+        self.sound_file = audio_path
         self.beep_needed = False
         self.initialised_file = None
 
     def initialise(self):
         try:
             self.initialised_file = simpleaudio.WaveObject.from_wave_file(
-                get_first_file_in_directory(self.sound_file)
+                self.sound_file
             )
-        except IndexError:
-            print(f"Can't find a valid file in {self.sound_file}. Using stock sounds.")
+        except FileNotFoundError:
             self.beep_needed = True
 
     def play_sound(self):
@@ -159,12 +157,10 @@ def sylo(
 
 
 def run(args):
-    global is_double
+    global is_double, timer_mode
     clear_screen()
 
     durations_data = Durations()
-    sound = Sound()
-    sound.initialise()
 
     if args.work_time:
         durations_data.work.mins = args.work_time
@@ -174,8 +170,13 @@ def run(args):
         durations_data.rest.secs = mins_to_secs(args.rest_time)
     if args.double_speed is True:
         is_double = True
+    if args.audio_file:
+        sound = Sound(audio_path=args.audio_file)
+    else:
+        sound = Sound()
+    print(args.audio_file)
+    sound.initialise()
 
-    timer_mode = 'work'
     sylo(
         durations_model=durations_data,
         sound_obj=sound,
