@@ -1,10 +1,6 @@
 import os
 
 
-def get_first_file_in_directory(path: str):
-    return path + os.listdir(path)[0]
-
-
 def clear_screen():
     os.system("cls" if os.name == "nt" else "clear")
 
